
var bSwitchViews = false;
				
var bStartTableView = false
				
var currModelId = "ID161233";
							
var currModelVersion = "";
						
var currModelName = "Define risk response ICS ERM";
			
var currModelType = "IT Service Process";
			 
var currMailAddress = "";
			
var bModInfoWindow = false;
				
var bPrintOne = false;				
				
var bPrintTwo = false;
				
var modInfo = new Array();
		
var overviewimage = new Image();
			
var modelimage68 = new Image();
			
var modelimage45 = new Image();
			
var modelimage90 = new Image();
			
if (!parent.header)
{
	var strPath = top.window.location.href;
	top.location.href= strPath.substring(0, strPath.lastIndexOf("/") + 1) + "../index.html?id=" + currModelId;
}
else
{
	var z = top.header.iZoom;
	checkLoadTableView();
}

function checkLoadTableView()
{
  if (bStartTableView && !parent.header.bModelLoaded)
  {
    top.model.location.href = "../" + currModelId + "/" + currModelId + "t.html"
  }
  else
  {
		overviewimage.src = "../overview/ID161233.png";
			
		if (z == 68) { modelimage68.src = "../images/ado25.png"; }
		else { window.setTimeout("eval(\"modelimage68.src = '../images/ado25.png'\");", 1000); }
			
		if (z == 45) { modelimage45.src = "../images/ado26.png"; }
		else { window.setTimeout("eval(\"modelimage45.src = '../images/ado26.png'\");", 1000); }
			
		if (z == 90) { modelimage90.src = "../images/ado27.png"; }
		else { window.setTimeout("eval(\"modelimage90.src = '../images/ado27.png'\");", 1000); }
			
	}
	parent.header.bModelLoaded = true;
}

function actualizeImageArea()
{
	prepareImageMap();
		
	createImageArea(5.16, 5.295, 7.84, 7.645, "ID168704", "ID161233", "ID168704", "", false);
					
	createImageArea(6, 8.97, 11.120000000000001, 10.69, "ID168700", "ID161233", "ID168700", "", false);
					
	createImageArea(5.5, 12.3, 7.5, 13.2, "ID168696", "ID161233", "ID168696", "", false);
					
	createImageArea(48.5, 30.61, 52.14, 33.19, "ID166723", "ID161233", "ID166723", "", false);
					
	createImageArea(47.715, 34.3, 50.265, 37.08, "ID166720", "ID161233", "ID166720", "", false);
					
	createImageArea(21.095, 35.795, 23.884999999999998, 38.144999999999996, "ID166712", "ID161233", "ID166712", "", false);
					
	createImageArea(22, 31.97, 24.68, 33.69, "ID166709", "ID161233", "ID166709", "", false);
					
	createImageArea(19, 12.3, 21, 13.2, "ID166691", "ID161233", "ID166691", "", false);
					
	createImageArea(22.5, 8.97, 26.82, 10.69, "ID166688", "ID161233", "ID166688", "", false);
					
	createImageArea(17, 8.97, 21.159999999999997, 10.69, "ID166685", "ID161233", "ID166685", "", false);
					
	createImageArea(16.16, 5.295, 18.84, 7.645, "ID166682", "ID161233", "ID166682", "", false);
					
	createImageArea(21.66, 5.295, 24.34, 7.645, "ID166679", "ID161233", "ID166679", "", false);
					
	createImageArea(19.764999999999997, 26.8, 22.215, 29.580000000000002, "ID161268", "ID161233", "ID161268", "", false);
					
	createImageArea(17.174999999999997, 19.294999999999998, 19.805, 22.505, "ID161265", "ID161233", "ID161265", "", false);
					
	createImageArea(43.21, 26.8, 45.79, 28.720000000000002, "ID161262", "ID161233", "ID161262", "", false);
					
	createImageArea(35.715, 19.294999999999998, 38.265, 21.645, "ID161259", "ID161233", "ID161259", "", false);
					
	createImageArea(56.3, 19.3, 57.7, 20.7, "ID161256", "ID161233", "ID161256", "", false);
					
	createImageArea(47.815, 18.615, 56.144999999999996, 22.365, "ID161253", "ID161233", "ID161253", "", false);
					
	createImageArea(40.375, 18.240000000000002, 47.245000000000005, 22.72, "ID161271", "ID161233", "ID161271", "", false);
					
	createImageArea(29.294999999999998, 19.294999999999998, 31.685, 22.505, "ID161250", "ID161233", "ID161250", "", false);
					
	createImageArea(27.875, 15.120000000000001, 33.505, 18.52, "ID161244", "ID161233", "ID161244", "", false);
					
	createImageArea(13.67, 19.3, 16.33, 22.080000000000002, "ID161247", "ID161233", "ID161247", "", false);
					
	createImageArea(22.375, 18.62, 28.005000000000003, 22.02, "ID161241", "ID161233", "ID161241", "", false);
					
	createImageArea(6.445, 18.24, 12.875, 22.02, "ID161238", "ID161233", "ID161238", "", false);
					
	createImageArea(3.9650000000000003, 19.3, 6.015000000000001, 22.080000000000002, "ID161235", "ID161233", "ID161235", "", false);
					
	imageMapsReady();
}
			
			ID161235D='';				
				ID161238D='<span class=\\\"mov_name\\\">Identify risk responses</span><span class=\"mov_desc\">\"Risk responses fall within the following categories:<br />• Avoidance – Action is taken to exit the activities giving rise to risk. Risk avoidance<br />may involve exiting a product line, declining expansion to a new geographical<br />market, or selling a division.<br />• Reduction – Action is taken to reduce the risk likelihood or impact, or both. This<br />may involve any of a myriad of everyday business decisions.<br />• Sharing – Action is taken to reduce risk likelihood or impact by transferring or<br />otherwise sharing a portion of the risk. Common risk-sharing techniques include<br />purchasing insurance products, pooling risks, engaging in hedging transactions, or<br />outsourcing an activity.<br />• Acceptance – No action is taken to affect likelihood or impact.\"<br />COSO</span>';				
				ID161241D='<span class=\\\"mov_name\\\">Select response</span>';				
				ID161244D='<span class=\\\"mov_name\\\">Align responses within portfolio</span>';				
				ID161247D='<span class=\\\"mov_name\\\">Evaluate possible risk responses</span>';				
				ID161250D='<span class=\\\"mov_name\\\">Response feasible from portfolio point of view?</span>';				
				ID161253D='<span class=\\\"mov_name\\\">Implement plan</span>';				
				ID161256D='<span class=\\\"mov_name\\\">End-31749</span>';				
				ID161259D='<span class=\\\"mov_name\\\">Change in IT service required?</span>';				
				ID161262D='<span class=\\\"mov_name\\\">Design IT service</span>';				
				ID161265D='<span class=\\\"mov_name\\\">IT service used and additional assessment from IT required?</span>';				
				ID161268D='<span class=\\\"mov_name\\\">Assess and evaluate specific IT risks</span>';				
				ID161271D='<span class=\\\"mov_name\\\">Develop implementation plan</span>';				
				ID166679D='<span class=\\\"mov_name\\\">ICS DRR - RM RiTr I1</span>';				
				ID166682D='<span class=\\\"mov_name\\\">ICS DRR - RM RiAc I1</span>';				
				ID166712D='<span class=\\\"mov_name\\\">ICS DRR - RM RiAs I1</span>';				
				ID166720D='<span class=\\\"mov_name\\\">ICS DRR - RM DoSaF I1</span>';				
				ID168704D='<span class=\\\"mov_name\\\">ICS DRR - RM RiTr I2</span>';				
				ID168700D='<span class=\\\"mov_name\\\">Def1</span>';				
				ID166685D='<span class=\\\"mov_name\\\">Def2</span>';				
				ID166688D='<span class=\\\"mov_name\\\">Def3</span>';				
				ID166709D='<span class=\\\"mov_name\\\">Def4</span>';				
				ID166723D='<span class=\\\"mov_name\\\">Def5</span>';				
				ID166691D='<span class=\\\"mov_name\\\">Develop implementation plan DP</span>';				
				ID168696D='<span class=\\\"mov_name\\\">Identify risk responses DP</span>';				
				
			
function readCM()
{
			ID161235CM = new instCM("Define risk response ICS ERM");
ID161238CM = new instCM("Identify risk responses");
ID161238CM.addAttribute("Responsible", "obj");
ID161238CM.addLink("Responsible", "javascript:openWindow(\"ID159353\", \"ID159394\");", "Risk officers", "small_role.png");
ID161238CM.addAttribute("Consulted", "obj");
ID161238CM.addLink("Consulted", "javascript:openWindow(\"ID159353\", \"ID159370\");", "Process Expert", "small_role.png");
ID161238CM.addAttribute("Input data", "obj");
ID161238CM.addLink("Input data", "javascript:openWindow(\"ID159427\", \"ID159513\");", "Risk strategy", "small_date.png");
ID161238CM.addLink("Input data", "javascript:openWindow(\"ID159427\", \"ID159504\");", "Risk catalogue", "small_date.png");
ID161238CM.addAttribute("Output data", "obj");
ID161238CM.addLink("Output data", "javascript:openWindow(\"ID159427\", \"ID159540\");", "Action plan", "small_date.png");
ID161241CM = new instCM("Select response");
ID161241CM.addAttribute("Responsible", "obj");
ID161241CM.addLink("Responsible", "javascript:openWindow(\"ID159353\", \"ID159394\");", "Risk officers", "small_role.png");
ID161241CM.addAttribute("Input data", "obj");
ID161241CM.addLink("Input data", "javascript:openWindow(\"ID159427\", \"ID159540\");", "Action plan", "small_date.png");
ID161241CM.addAttribute("Output data", "obj");
ID161241CM.addLink("Output data", "javascript:openWindow(\"ID159427\", \"ID159540\");", "Action plan", "small_date.png");
ID161244CM = new instCM("Align responses within portfolio");
ID161244CM.addAttribute("Responsible", "obj");
ID161244CM.addLink("Responsible", "javascript:openWindow(\"ID159353\", \"ID159394\");", "Risk officers", "small_role.png");
ID161244CM.addAttribute("Input data", "obj");
ID161244CM.addLink("Input data", "javascript:openWindow(\"ID159427\", \"ID159540\");", "Action plan", "small_date.png");
ID161244CM.addAttribute("Output data", "obj");
ID161244CM.addLink("Output data", "javascript:openWindow(\"ID159427\", \"ID159540\");", "Action plan", "small_date.png");
ID161247CM = new instCM("Evaluate possible risk responses");
ID161247CM.addAttribute("Referenced subprocess", "mod");
ID161247CM.addLink("Referenced subprocess", "../ID161309/ID161309.html", "Evaluate possible risk responses ICS ERM", "mt_itsp.gif");
ID161250CM = new instCM("Response feasible from portfolio point of view?");
ID161253CM = new instCM("Implement plan");
ID161253CM.addAttribute("Responsible", "obj");
ID161253CM.addLink("Responsible", "javascript:openWindow(\"ID159353\", \"ID159406\");", "Risk Owner", "small_role.png");
ID161253CM.addAttribute("Accountable", "obj");
ID161253CM.addLink("Accountable", "javascript:openWindow(\"ID159353\", \"ID159403\");", "Risk Manager", "small_role.png");
ID161253CM.addAttribute("Consulted", "obj");
ID161253CM.addLink("Consulted", "javascript:openWindow(\"ID159353\", \"ID159364\");", "IT Expert", "small_role.png");
ID161253CM.addLink("Consulted", "javascript:openWindow(\"ID159353\", \"ID159370\");", "Process Expert", "small_role.png");
ID161253CM.addAttribute("Informed", "obj");
ID161253CM.addLink("Informed", "javascript:openWindow(\"ID159353\", \"ID159355\");", "Senior Management", "small_role.png");
ID161253CM.addAttribute("Input data", "obj");
ID161253CM.addLink("Input data", "javascript:openWindow(\"ID159427\", \"ID159435\");", "Process documentation", "small_date.png");
ID161256CM = new instCM("End-31749");
ID161259CM = new instCM("Change in IT service required?");
ID161262CM = new instCM("Design IT service");
ID161262CM.addAttribute("Referenced subprocess", "mod");
ID161262CM.addLink("Referenced subprocess", "../ID158865/ID158865.html", "Design IT service", "mt_itsp.gif");
ID161265CM = new instCM("IT service used and additional assessment from IT required?");
ID161268CM = new instCM("Assess and evaluate specific IT risks");
ID161268CM.addAttribute("Referenced subprocess", "mod");
ID161268CM.addLink("Referenced subprocess", "../ID160769/ID160769.html", "Assess and evaluate IT risks ICS", "mt_itsp.gif");
ID161271CM = new instCM("Develop implementation plan");
ID161271CM.addAttribute("Responsible", "obj");
ID161271CM.addLink("Responsible", "javascript:openWindow(\"ID159353\", \"ID159406\");", "Risk Owner", "small_role.png");
ID161271CM.addAttribute("Accountable", "obj");
ID161271CM.addLink("Accountable", "javascript:openWindow(\"ID159353\", \"ID159403\");", "Risk Manager", "small_role.png");
ID161271CM.addAttribute("Consulted", "obj");
ID161271CM.addLink("Consulted", "javascript:openWindow(\"ID159353\", \"ID159370\");", "Process Expert", "small_role.png");
ID161271CM.addLink("Consulted", "javascript:openWindow(\"ID159353\", \"ID159403\");", "Risk Manager", "small_role.png");
ID161271CM.addLink("Consulted", "javascript:openWindow(\"ID159353\", \"ID159364\");", "IT Expert", "small_role.png");
ID161271CM.addAttribute("Input data", "obj");
ID161271CM.addLink("Input data", "javascript:openWindow(\"ID159427\", \"ID159540\");", "Action plan", "small_date.png");
ID161271CM.addAttribute("Output data", "obj");
ID161271CM.addLink("Output data", "javascript:openWindow(\"ID159427\", \"ID159438\");", "Organisational structure", "small_date.png");
ID161271CM.addLink("Output data", "javascript:openWindow(\"ID159427\", \"ID159435\");", "Process documentation", "small_date.png");
ID161274CM = new instCM("Business");
ID161277CM = new instCM("IT");
ID166679CM = new instCM("ICS DRR - RM RiTr I1");
ID166679CM.addAttribute("Referenced subprocess", "mod");
ID166679CM.addLink("Referenced subprocess", "../ID159283/ID159283.html", "IT Risk Treatment - ICS", "mt_itsp.gif");
ID166679CM.addAttribute("Referenced Interface Process", "obj");
ID166679CM.addLink("Referenced Interface Process", "javascript:openWindow(\"ID159283\", \"ID167747\");", "RM RiTr - ICS DRR I1", "small_ipro.png");
ID166682CM = new instCM("ICS DRR - RM RiAc I1");
ID166682CM.addAttribute("Referenced subprocess", "mod");
ID166682CM.addLink("Referenced subprocess", "../ID159181/ID159181.html", "IT Risk Acceptance - ICS", "mt_itsp.gif");
ID166682CM.addAttribute("Referenced Interface Process", "obj");
ID166682CM.addLink("Referenced Interface Process", "javascript:openWindow(\"ID159181\", \"ID167742\");", "RM RiAc - ICS DRR I1", "small_ipro.png");
ID166712CM = new instCM("ICS DRR - RM RiAs I1");
ID166712CM.addAttribute("Referenced subprocess", "mod");
ID166712CM.addLink("Referenced subprocess", "../ID159221/ID159221.html", "IT Risk Assessment - ICS", "mt_itsp.gif");
ID166712CM.addAttribute("Referenced Interface Process", "obj");
ID166712CM.addLink("Referenced Interface Process", "javascript:openWindow(\"ID159221\", \"ID167752\");", "RM RiAs - ICS DRR I1", "small_ipro.png");
ID166720CM = new instCM("ICS DRR - RM DoSaF I1");
ID166720CM.addAttribute("Referenced subprocess", "mod");
ID166720CM.addLink("Referenced subprocess", "../ID159057/ID159057.html", "IT Definition of Scope and Framework - ICS", "mt_itsp.gif");
ID166720CM.addAttribute("Referenced Interface Process", "obj");
ID166720CM.addLink("Referenced Interface Process", "javascript:openWindow(\"ID159057\", \"ID167769\");", "RA DoSaF- ICS DRR I1", "small_ipro.png");
ID168704CM = new instCM("ICS DRR - RM RiTr I2");
ID168704CM.addAttribute("Referenced subprocess", "mod");
ID168704CM.addLink("Referenced subprocess", "../ID163691/ID163691.html", "IT Risk Treatment - CGF", "mt_itsp.gif");
ID168704CM.addAttribute("Referenced Interface Process", "obj");
ID168704CM.addLink("Referenced Interface Process", "javascript:openWindow(\"ID159283\", \"ID168717\");", "RM RiTr - ICS DRR I2", "small_ipro.png");
ID168700CM = new instCM("Def1");
ID168700CM.addAttribute("Data", "obj");
ID168700CM.addLink("Data", "javascript:openWindow(\"ID158601\", \"ID158726\");", "D75 Class. risk treatment options", "small_date.png");
ID166685CM = new instCM("Def2");
ID166685CM.addAttribute("Data", "obj");
ID166685CM.addLink("Data", "javascript:openWindow(\"ID158601\", \"ID158750\");", "D77 Approved Activity Lists", "small_date.png");
ID166688CM = new instCM("Def3");
ID166688CM.addAttribute("Data", "obj");
ID166688CM.addLink("Data", "javascript:openWindow(\"ID158601\", \"ID158720\");", "D28 Risk treatment decision", "small_date.png");
ID166709CM = new instCM("Def4");
ID166709CM.addAttribute("Data", "obj");
ID166709CM.addLink("Data", "javascript:openWindow(\"ID159427\", \"ID159507\");", "IT risks catalogue", "small_date.png");
ID166723CM = new instCM("Def5");
ID166723CM.addAttribute("Data", "obj");
ID166723CM.addLink("Data", "javascript:openWindow(\"ID159427\", \"ID159435\");", "Process documentation", "small_date.png");
ID166723CM.addLink("Data", "javascript:openWindow(\"ID159427\", \"ID159438\");", "Organisational structure", "small_date.png");
ID166723CM.addLink("Data", "javascript:openWindow(\"ID159427\", \"ID159540\");", "Action plan", "small_date.png");
ID166691CM = new instCM("Develop implementation plan DP");
ID168696CM = new instCM("Identify risk responses DP");
ID161280CM = new instCM("");
ID161281CM = new instCM("");
ID161282CM = new instCM("");
ID161283CM = new instCM("");
ID161284CM = new instCM("");
ID161285CM = new instCM("");
ID161286CM = new instCM("");
ID161287CM = new instCM("");
ID161288CM = new instCM("");
ID161289CM = new instCM("");
ID161290CM = new instCM("");
ID161291CM = new instCM("");
ID161292CM = new instCM("");
ID161293CM = new instCM("");
ID161294CM = new instCM("");
ID161295CM = new instCM("");
ID161296CM = new instCM("");
ID161297CM = new instCM("");
ID161298CM = new instCM("");
ID161299CM = new instCM("");
ID161300CM = new instCM("");
ID161301CM = new instCM("");
ID161302CM = new instCM("");
ID161303CM = new instCM("");
ID161304CM = new instCM("");
ID161305CM = new instCM("");
ID161306CM = new instCM("");
ID161307CM = new instCM("");
ID166700CM = new instCM("");
ID166701CM = new instCM("");
ID166702CM = new instCM("");
ID166704CM = new instCM("");
ID166705CM = new instCM("");
ID166706CM = new instCM("");
ID166707CM = new instCM("");
ID166708CM = new instCM("");
ID166715CM = new instCM("");
ID166717CM = new instCM("");
ID166726CM = new instCM("");
ID166729CM = new instCM("");
ID166760CM = new instCM("");
ID166762CM = new instCM("");
ID166779CM = new instCM("");
ID167075CM = new instCM("");
ID167076CM = new instCM("");
ID167764CM = new instCM("");
ID168694CM = new instCM("");
ID168695CM = new instCM("");
ID168699CM = new instCM("");
ID168703CM = new instCM("");
ID168707CM = new instCM("");
ID168708CM = new instCM("");
ID168709CM = new instCM("");
ID168710CM = new instCM("");
}
		